@@ -27,6 +27,7 @@ nh_lgb_model_url_nostrict = cfg['nh_lgb_model_url']['nostrict']  # loose
 if not Path('vocab.txt').exists():
     download(vocab_url, 'vocab.txt')
 tokenizer = Tokenizer('vocab.txt', do_lower_case=True)
+text2seq = functools.partial(text2seq, tokenizer=tokenizer)  # hook
 
 download(nh_bert_model_url_strict, 'nh_bert_strict')
 download(nh_bert_model_url_nostrict, 'nh_bert_nostrict')
@@ -41,11 +42,12 @@ nh_lgb_strict = joblib.load('nh_lgb_strict')
 nh_lgb_nostrict = joblib.load('nh_lgb_nostrict')
 
 logger.info("初始化KerasModel")
-logger.info(nh_bert_strict.predict(text2seq("文本", tokenizer)))
-logger.info(nh_bert_nostrict.predict(text2seq("文本", tokenizer)))
+logger.info(nh_bert_strict.predict(text2seq("文本")))
+logger.info(nh_bert_nostrict.predict(text2seq("文本")))
 
 
 # 打分融合
+@logger.catch()
 def merge_score(X, text="", mode_type='strict'):
     if mode_type == 'strict':
         pred1 = nh_lgb_strict.predict_proba(X)[:, 1]
@@ -53,18 +55,19 @@ def merge_score(X, text="", mode_type='strict'):
         pred = (pred1 * 0.8 + pred2 * 0.2)[0]
 
     else:
-        pred1 = nh_lgb_nostrict.predict_proba(X)[:, 1]
-        pred2 = nh_bert_nostrict.predict(text2seq(text))[:, 1]
-        pred = (pred1 * 0.8 + pred2 * 0.2)[0]
+        pred1 = nh_lgb_nostrict.predict_proba(X)[:, 1].tolist()[0]
+        pred2 = nh_bert_nostrict.predict(text2seq(text))[:, 1].tolist()[0]
+        pred = pred1 * 0.8 + pred2 * 0.2
 
     _ = {'prob': [pred1, pred2], 'checkSuggestion': 'PASS' if pred > 0.8 else 'REVIEW'}
 
+    logger.info(_)
+
     return _
 
 
-# Api
 def get_feats(ac):
-    logger.info(ac)
+    # logger.info(ac)  # close logger
 
     _ = ac.pop('category')
     articleInfo = ArticleInfo(**ac)
@@ -76,6 +79,8 @@ def get_feats(ac):
     return [r]
 
 
+# Api
+# @logger.catch
 def predict_strict(**ac):
     X = get_feats(ac)
     text = ac.get("title", "请输入一个文本")
